package cz.cvut.kbss.reporting.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.security.crypto.password.PasswordEncoder;

import javax.persistence.*;
import java.util.Objects;

@Getter
@Setter
@Entity
@NamedQueries({@NamedQuery(name = "Person.findByUsername", query = "SELECT p FROM Person p WHERE p.username = :username")})
public class Person extends AbstractEntity {

    @Basic(optional = false)
    @Column(nullable = false, length = 20)
    private String firstName;

    @Basic(optional = false)
    @Column(nullable = false, length = 20)
    private String lastName;

    @Basic(optional = false)
    @Column(nullable = false, unique = true, length = 20)
    private String username;

    // This means that password won't be sent to the client, but it is still possible to update it
    // Because it will be deserialized when received in JSON from the client
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    @Basic(optional = false)
    @Column(nullable = false)
    private String password;    // No need to store salt, BCrypt (which we use) generates random salt automatically

    /**
     * Encodes the person's password.
     *
     * @param encoder The password encoder to use
     */
    public void encodePassword(PasswordEncoder encoder) {
        Objects.requireNonNull(encoder);
        if (password != null) {
            this.password = encoder.encode(password);
        }
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Person)) return false;

        Person person = (Person) o;

        if (firstName != null ? !firstName.equals(person.firstName) : person.firstName != null) return false;
        if (lastName != null ? !lastName.equals(person.lastName) : person.lastName != null) return false;
        return username != null ? username.equals(person.username) : person.username == null;
    }

    @Override
    public int hashCode() {
        int result = firstName != null ? firstName.hashCode() : 0;
        result = 31 * result + (lastName != null ? lastName.hashCode() : 0);
        result = 31 * result + (username != null ? username.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return firstName + " " + lastName + " (" + username + ")";
    }
}
