package cz.cvut.kbss.reporting.rest.mapper;

import cz.cvut.kbss.reporting.dto.OccurrenceDto;
import cz.cvut.kbss.reporting.dto.OccurrenceReportDetailDto;
import cz.cvut.kbss.reporting.dto.OccurrenceReportDto;
import cz.cvut.kbss.reporting.dto.PersonDto;
import cz.cvut.kbss.reporting.model.EventInfo;
import cz.cvut.kbss.reporting.model.Occurrence;
import cz.cvut.kbss.reporting.model.OccurrenceReport;
import cz.cvut.kbss.reporting.model.Person;
import cz.cvut.kbss.reporting.model.Tag;
import java.util.List;
import java.util.stream.Collectors;
import org.mapstruct.Mapper;

@Mapper(componentModel = "spring")
public abstract class DtoMapper {

    public abstract OccurrenceReportDto reportToReportDto(OccurrenceReport report);

    public abstract OccurrenceReport reportDetailDtoToReport(OccurrenceReportDetailDto report);

    public OccurrenceDto occurrenceToOccurrenceDto(Occurrence occurrence) {
        if ( occurrence == null ) {
            return null;
        }

        OccurrenceDto occurrenceDto = new OccurrenceDto();

        occurrenceDto.setId( occurrence.getId() );
        occurrenceDto.setName( occurrence.getName() );
        occurrenceDto.setSeverity( occurrence.getSeverity() );
        occurrenceDto.setType( occurrence.getType() );
        occurrenceDto.setStartTime( occurrence.getTime().getStartTime());
        occurrenceDto.setEndTime( occurrence.getTime().getEndTime());

        return occurrenceDto;
    }

    public Occurrence occurrenceDtoToOccurrence(OccurrenceDto occurrenceDto) {
        if ( occurrenceDto == null ) {
            return null;
        }

        Occurrence occurrence = new Occurrence();
        occurrence.setId( occurrenceDto.getId() );
        occurrence.setName( occurrenceDto.getName() );
        occurrence.setSeverity( occurrenceDto.getSeverity() );
        occurrence.setType( occurrenceDto.getType() );
        occurrence.setTime( new EventInfo() );
        occurrence.getTime().setStartTime( occurrenceDto.getStartTime());
        occurrence.getTime().setEndTime( occurrenceDto.getEndTime());

        return occurrence;
    }

    public abstract Person personDtoToPerson(PersonDto dto);

    public List<String> tagToName(List<Tag> tags) {
        if (tags == null) {
            return null;
        }
        return tags.stream().map(Tag::getName).collect(Collectors.toList());
    }
}
