'use strict';

import React from "react";
import PropTypes from "prop-types";
import {Button, Modal} from "react-bootstrap";
import {FormattedMessage} from "react-intl";
import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";

const DeleteReportDialog = (props) => {
    return <Modal show={props.show} onHide={props.onClose}>
        <Modal.Header closeButton>
            <Modal.Title>
                <FormattedMessage id='delete-dialog.title' values={{type: props.reportType}}/>
            </Modal.Title>
        </Modal.Header>
        <Modal.Body>
            {props.i18n('delete-dialog.content')}
        </Modal.Body>
        <Modal.Footer>
            <Button bsStyle='warning' bsSize='small' onClick={props.onSubmit}>{props.i18n('delete')}</Button>
            <Button bsSize='small' onClick={props.onClose}>{props.i18n('cancel')}</Button>
        </Modal.Footer>
    </Modal>;
};

DeleteReportDialog.propTypes = {
    onClose: PropTypes.func.isRequired,
    onSubmit: PropTypes.func.isRequired,
    show: PropTypes.bool.isRequired,
    reportType: PropTypes.string
};

export default injectIntl(I18nWrapper(DeleteReportDialog));
